@@ -451,7 +451,8 @@ class EditCommands(Commands):
                 if posto <= posfrom:
                     break
                     
-                sel = wnd.screen.selection.get_rect_selection(posfrom)
+                sel = wnd.screen.selection.get_col_string(
+                        posfrom, colfrom, colto)
                 if sel:
                     f, t, org = sel
                     if org.endswith('\n'):
@@ -480,7 +481,6 @@ class EditCommands(Commands):
         else:
             self.insert_string(wnd, wnd.cursor.pos, s)
 
-
     def delete_sel(self, wnd):
         if wnd.screen.selection.is_selected():
             if not wnd.screen.selection.is_rectangular():
@@ -501,7 +501,8 @@ class EditCommands(Commands):
                 ) = wnd.screen.selection.get_rect_range()
 
             while posfrom < posto:
-                sel = wnd.screen.selection.get_rect_selection(posfrom)
+                sel = wnd.screen.selection.get_col_string(
+                        posfrom, colfrom, colto)
                 if sel:
                     f, t, org = sel
                     if org.endswith('\n'):
@@ -760,7 +761,8 @@ class EditCommands(Commands):
                     ) = wnd.screen.selection.get_rect_range()
     
                 while posfrom < posto:
-                    sel = wnd.screen.selection.get_rect_selection(posfrom)
+                    sel = wnd.screen.selection.get_col_string(
+                            posfrom, colfrom, colto)
                     if sel:
                         f, t, org = sel
                         s.append(org.rstrip('\n'))
@@ -771,7 +773,10 @@ class EditCommands(Commands):
                 return '\n'.join(s)
 
     def _copy_sel(self, wnd):
-        kaa.app.clipboard = self._get_sel(wnd)
+        sel = self._get_sel(wnd)
+        if sel:
+            kaa.app.set_clipboard(sel)
+        return sel
         
     @command('edit.copy')
     def copy(self, wnd):
@@ -780,14 +785,15 @@ class EditCommands(Commands):
 
     @command('edit.cut')
     def cut(self, wnd):
-        self._copy_sel(wnd)
-        self.delete_sel(wnd)
+        if self._copy_sel(wnd):
+            self.delete_sel(wnd)
         wnd.screen.selection.clear()
 
     @command('edit.paste')
     def paste(self, wnd):
-        if kaa.app.clipboard:
-            self.put_string(wnd, kaa.app.clipboard)
+        s = kaa.app.get_clipboard()
+        if s:
+            self.put_string(wnd, s)
             wnd.screen.selection.clear()
 
     @command('edit.conv.upper')
@@ -825,6 +831,13 @@ class EditCommands(Commands):
         from kaa.ui.wordcomplete import wordcompletemode
         wordcompletemode.show_wordlist(wnd)
 
+    @command('edit.clipboard-history')
+    @norec
+    @norerun
+    def clipboard_history(self, wnd):
+        from kaa.ui.clipboardhist import clipboardhistmode
+        clipboardhistmode.show_history(wnd)
+
 class CodeCommands(Commands):
     @command('code.region.linecomment')
     def linecomment(self, wnd):
