@@ -8,9 +8,9 @@ DefaultThemes = {
             Style('parenthesis_cur', 'White', 'Blue'),
             Style('parenthesis_match', 'Red', 'Yellow'),
 
-            Style('keyword', 'Magenta', 'default'),
-            Style('comment', 'blue', 'default'),
-            Style('string', 'Green', 'default'),
-            Style('number', 'Yellow', 'default'),
+            Style('keyword', 'Red', 'default'),
+            Style('comment', 'Cyan', 'default'),
+            Style('string', 'Blue', 'default'),
+            Style('number', 'Green', 'default'),
         ])
 }
